
(********************************************************)
(*                                                      *)
(*           Sample Unit Game for Delphi 5              *)
(*        Copyright (c) 2001 by Adam Boduch             *)
(*          HTTP://WWW.PROGRAMOWANIE.OF.PL              *)
(*              E - mail: boduch@poland.com             *)
(*      Build: 10.01.2001 r.                            *)
(*                                                      *)
(********************************************************)

unit Samo;

interface

uses
  SysUtils, Classes, ExtCtrls;

{ Oto pozycje w jakich moze sie znajdowac pojazd: }
const
  stStart = 0;
  stStop = 1;
  stPit = 2;

{
  Oto nowy typ - przedstawia on samochody do wykorzystania
  w aplikacji
}
type
  TCars = (caPorshe, caFerrari, caLamborgini);

  TSamochod = class  // nasza nowa klasa
  private
    MaxPredkosc : Integer; // max predkosc jaka moze oosiagnac pojazd
    Rodzaj : TCars; // typ pojazdu ( zmienna wskazuje na nasz nowy typ )
    Predkosc : Integer; // aktualna predkosc poruszania sie pojazdu
    Timer : TTimer;  // wskazanie na komponent "TTimer"
  protected
    procedure Jedz(Speed : Integer); // procedura, ktora powoduje porusznie pojazdu
    procedure Stop; // zatrzymanie poruszania sie pojazdu
    procedure OnTimer(Sender: TObject);
  public
    Paliwo : Integer; // ilosc paliwa
    Interval : Integer; // czestotliwosc wystepowania zdarzenia czasowego
    constructor Create(Model : TCars = caPorshe; Pal : Integer = 100);
    destructor Destroy; override;
    function JakaPredkosc : Integer; // podaje aktualna predkosc
    function Go(Pred: Integer; Polecenie : Integer; var Odp: String) : Boolean;
    function ZmienOpony : Integer; // funkcja, ktora zmienia opony
    function Zatankuj(IlePaliwa: Byte) : Integer; // funkcja zwiekszajaca ilosc paliwa
  end;

implementation

{ TSamochod }

constructor TSamochod.Create(Model: TCars; Pal : Integer);
begin
  inherited Create;
    Rodzaj := Model;
    Paliwo := Pal;
{
  W zaleznosci od wybranego modelu ustalana jest max. predkosc
  poruszania sie tegoz pojazdu.
}
    case Model of
      caPorshe: MaxPredkosc := 280;
      caFerrari : MaxPredkosc := 310;
      caLamborgini : MaxPredkosc := 290;
    end;
  Interval := 0; // wyzeruj zmienna
{
  Otworz obiekt typu "TTimer" i ustaw jego wlasciwosci. Ustawiany jest
  czas wystepowania zdarzenia na podst. zmiennej "Interval", komponent
  jest aktywowany, a nastepnie zostaje przypisane zdarzenie typu "OnTimer"
}
  Timer := TTimer.Create(nil);
  Timer.Interval := Interval;
  Timer.Enabled := True;
  Timer.OnTimer := OnTimer;
end;

destructor TSamochod.Destroy;
begin
  Timer.Free; // przy zamykaniu zwolnij obiekt Timer
  inherited;
end;

function TSamochod.Go(Pred: Integer; Polecenie : Integer; var Odp: String): Boolean;
begin
{
  Procedura do wysylania polecen. To tutaj sie ustawia, czy pojazd
  ma jechac, czy tez nie. Tutaj takze sprawdzane jest, czy nie probujemy
  przypisac predkosci do pojazdu, ktory nie jest w stanie jej rozwinac.
}
  Result := True;
  Predkosc := Pred; // ustawianie predkosci
  case Polecenie of // w zalezbnosci od wybranej opcji:
    stStart : // powoduje start pojazdu
    begin
{ Sprawdzane jest tutaj, czy nie probowalismy danemu pojazdowi przypisac
  predkosci jakiej nie zdolalby rozwinac }
      if (Rodzaj = caPorshe) and (Predkosc > 280) then
      begin
        Odp := 'Nie mog jecha tak szybko!'; // przypisanie odpowiedniego tekstu
        Result := False; // wynik operacji jako bledny
      end else Jedz(Predkosc); // w przeciwnym wypadku wykonaj procedure
      if (Rodzaj = caFerrari) and (Predkosc > 310) then
      begin        { j/w }
        Odp := 'Nie mog jecha tak szybko!';
        Result := False;
        Exit;
      end else Jedz(Predkosc);
      if (Rodzaj = caLamborgini) and (Predkosc > 290) then
      begin
        Odp := 'Nie moge jecha tak szybko!';
        Result := False;
        Exit;
      end else Jedz(Predkosc);
    end;
    stStop : // Jezeli pojazd ma byc zatrzymany...
    begin
      Stop; // wywyolaj odpowiednia procedure
      Result := True;  // wynik operacji jako pozytywny
      Odp := 'Tak jest! Zatrzymuje si!'; // wygeneruj tekst
      Exit; // dalej nie rob juz nic
    end;
    stPit : // Jezeli pojazd ma zjechac do PitStopu...
    begin
      Stop; // wywolaj odpowiednia procedure
      Result := True; 
      Odp := 'Wjechaem wanie do PitStopu-u!'; // wygeneruj tekst
      Exit;
    end;
  end;

{
  Jezeli wszystko sie powiedzie to przypisz zmiennej odpowiedni tekst.
}
  if Result then
    Odp := Format('Zrozumiaem. Jad z prdkoci %d km\h', [Predkosc]);
end;

function TSamochod.JakaPredkosc: Integer;
begin
{
  Funkcja zwraca rezultad w postaci predkosci z jaka jedzie pojazd.
  Dodatkowo w zaleznosci od predkosci do zmiennej "Interva" przypisywane
  sa odpowiednie wartosci majace symbolizowac przedzial, w ktorym bedzie
  generowane odpowiednie zdarzenie "OnTimer".
}
  Result := Predkosc;
  case Result of
    0..50: Interval := 10000;
    51..100: Interval := 6000;
    101..200: Interval := 2000;
    201..300: Interval := 1000;
    301..310: Interval := 600;
  end;
  Timer.Interval := Interval; // przypisz do komponentu
end;

procedure TSamochod.Jedz(Speed: Integer);
begin
// ustaw predkosc w zaleznosci od podanego w zemiennej "Speed" parametru
  Predkosc := Speed;
end;

procedure TSamochod.OnTimer(Sender: TObject);
begin
// W wypadku wystapienia zdarzenia zmniejszaj ilosc paliwa
  Paliwo := Pred(Paliwo);
end;

procedure TSamochod.Stop;
begin
  Predkosc := 0;  // zatrzymaj pojazd
end;

function TSamochod.Zatankuj(IlePaliwa: Byte) : Integer;
begin
// zwieksz ilosc paliwa w zaleznosci od podanej wartosci
  Paliwo := Paliwo + IlePaliwa;
  Result := Paliwo; // zwroc rezultad w postaci ilosci paliwa znajdujacego sie w baku
end;

function TSamochod.ZmienOpony: Integer;
begin
// funkcja zmienia opony, czyli na nowo podaje jej stan na 100%
  Result := 100;
end;

end.
