
(****************************************************)
{                                                    }
{          TeXT Edit  1.0  Source                    }
{       Copyright (c) 2000 by Adam Boduch            }
{         All rights reserved                        }
{                                                    }
{        SERVICE   FOR  PROGRAMMERS                  }
{                                                    }
{        E-mail: boduch@poland.com                   }
{     http://www.programowanie.of.pl                 }
(****************************************************)

unit MainFrmU;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ToolWin, ExtCtrls, ImgList, Menus;

const
  AppName = 'TeXT Edit 1.0'; // nazwa aplikacji

type
  TMainFrm = class(TForm)
    ControlBar1: TControlBar;
    Tools: TToolBar;
    RichEdit: TRichEdit;
    btnNew: TToolButton;
    btnOpen: TToolButton;
    OpenDialog: TOpenDialog;
    btnSave: TToolButton;
    SaveDialog: TSaveDialog;
    btnSaveAs: TToolButton;
    ImageList: TImageList;
    HelpBar: TStatusBar;
    MainMenu1: TMainMenu;
    Plik1: TMenuItem;
    FileNew: TMenuItem;
    FileOpen: TMenuItem;
    FileSave: TMenuItem;
    FileSaveAs: TMenuItem;
    N1: TMenuItem;
    FilePrint: TMenuItem;
    FilePrintSetup: TMenuItem;
    N2: TMenuItem;
    Wyjcie1: TMenuItem;
    Edit: TMenuItem;
    EditSelAll: TMenuItem;
    EditDel: TMenuItem;
    N3: TMenuItem;
    EditCut: TMenuItem;
    EditCopy: TMenuItem;
    EditPaste: TMenuItem;
    N4: TMenuItem;
    WordWrap: TMenuItem;
    Help: TMenuItem;
    HelpAbout: TMenuItem;
    ToolButton1: TToolButton;
    btnCut: TToolButton;
    btnCopy: TToolButton;
    btnPaste: TToolButton;
    procedure FormCreate(Sender: TObject);
    procedure btnOpenClick(Sender: TObject);
    procedure btnNewClick(Sender: TObject);
    procedure btnSaveClick(Sender: TObject);
    procedure btnSaveAsClick(Sender: TObject);
    procedure HelpAboutClick(Sender: TObject);
    procedure btnCutClick(Sender: TObject);
    procedure btnCopyClick(Sender: TObject);
    procedure btnPasteClick(Sender: TObject);
  private
    procedure OpenFile(FName : String);
  public
    { Public declarations }
  end;

var
  MainFrm: TMainFrm;

implementation

uses AboutFrmU;

{$R *.DFM}

procedure TMainFrm.FormCreate(Sender: TObject);
begin
// wyswietlenie tytulu aplikacji na pasku
  Caption := AppName;
end;

procedure TMainFrm.btnOpenClick(Sender: TObject);
begin
{ Proceudra wczytuje do RichEdit plik tekstowy }

  OpenDialog.Execute; // wywolanie okna ( wyswietlanie ).
  OpenFile(OpenDialog.FileName);
end;

procedure TMainFrm.OpenFile(FName: String);
begin
{ Wczytaj do RichEdit plik tekstowy. Wlasciwosc "FileName" komponentu
  "OpenDialog" przechowuje nazwe pliku tekstowego }
  RichEdit.Lines.LoadFromFile(FName);
// wyswietlenie na pasku tytulowym nazwy wczytanego pliku
  Caption := ExtractFileName(FName) + ' - ' + AppName;
end;

procedure TMainFrm.btnNewClick(Sender: TObject);
begin
{
  Ta procedura czysci zawartosc komponentu Memo. Jeeli plik
  nie zostal zapisany wyswietli sie pytanie. Jezeli urzytkownik
  wybierze "Tak" nastapi zapisanie plik poprzez wywolanie procedury
  "btnSave"
}
  if RichEdit.Modified then
   if MessageBox(Handle, 'Plik nie zosta zapisany, czy zapisa?',
   AppName, MB_YESNO + MB_ICONINFORMATION) = mrYes then
     btnSaveClick(Sender);
     RichEdit.Clear;
end;

procedure TMainFrm.btnSaveClick(Sender: TObject);
begin
{
  Jezeli plik nie zostal wczesniej zapisany wywolana
  zostaje procedura "btnSaveAsClick". Jezeli plik zostal juz
  wczesniej zapisany nastepuje zapisanie pliku bez
  wywolywania okna "Otwrz".
}
  if SaveDialog.FileName = '' then // jezeli nie znamy nazwy pliku
    btnSaveAsClick(Sender) // wywolaj procedure...
  else //... w przeciwnym wypadku zapisz plik...
    RichEdit.Lines.SaveToFile(SaveDialog.FileName);
end;

procedure TMainFrm.btnSaveAsClick(Sender: TObject);
begin
{
  W tej procedurze nastepuje wywolanie okna "Otworz", a
  nastepnie zapisanie pliku. Wartosc "SaveDialog.FileName"
  przechowuje sciezke pliku tekstowego pod jakim zapisales
  swoj dokument. Na samym koncu nastepuje zmiana wlasciwoscie
  "Caption" okna, a pozniej ustawienie wartosci "Modified" na
  "False"
}
  if SaveDialog.Execute then
  begin
    with SaveDialog do // instrukcja wiazaca
    begin
{
  Kazdy filtr zawiera okreslony numer od 1 do ilosci
  Twoich filtrow. Wlasciwosc "DefaultExt" zawiera info
  o domyslnym filtrze.
}
      case FilterIndex of // w zaleznosci od indeksu
        1:  DefaultExt := '.txt'; // przypisz domyslny filtr
        2:  DefaultExt := '.ini';
        3:  DefaultExt := '.wri';
        4:  DefaultExt := '';
      end;

    if FilterIndex = 3 then // jezeli jest to *.wri to zmien styl RichEdit'a
      RichEdit.PlainText := False
    else RichEdit.PlainText := True;
    end;

    RichEdit.Lines.SaveToFile(SaveDialog.FileName + SaveDialog.DefaultExt); // zapisz plik
    Caption := ExtractFileName(SaveDialog.FileName) + ' - ' + AppName;
    RichEdit.Modified := False; // ustaw wartosc na "False"
  end;
end;

procedure TMainFrm.HelpAboutClick(Sender: TObject);
begin
  AboutFrm := TAboutFrm.Create(Self); // stwrz
  AboutFrm.ShowModal; // wyswietl
  AboutFrm.Free; // zwolnij pamiec
end;

procedure TMainFrm.btnCutClick(Sender: TObject);
begin
  RichEdit.CutToClipboard; // wytnij tekst
end;

procedure TMainFrm.btnCopyClick(Sender: TObject);
begin
  RichEdit.CopyToClipboard; // skopiuj
end;

procedure TMainFrm.btnPasteClick(Sender: TObject);
begin
  RichEdit.PasteFromClipboard; // wklej do RichEdit
end;

end.
